@@ -36,7 +36,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("AssignProject", params)
+            headers = request.headers
+            body = self.call("AssignProject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.AssignProjectResponse()
@@ -64,7 +65,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBackupDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateBackupDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBackupDBInstanceResponse()
@@ -92,7 +94,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateBackupDownloadTask", params)
+            headers = request.headers
+            body = self.call("CreateBackupDownloadTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateBackupDownloadTaskResponse()
@@ -120,7 +123,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBInstance", params)
+            headers = request.headers
+            body = self.call("CreateDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBInstanceResponse()
@@ -148,7 +152,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateDBInstanceHour", params)
+            headers = request.headers
+            body = self.call("CreateDBInstanceHour", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateDBInstanceHourResponse()
@@ -176,7 +181,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAsyncRequestInfo", params)
+            headers = request.headers
+            body = self.call("DescribeAsyncRequestInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAsyncRequestInfoResponse()
@@ -208,7 +214,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupAccess", params)
+            headers = request.headers
+            body = self.call("DescribeBackupAccess", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupAccessResponse()
@@ -236,7 +243,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeBackupDownloadTask", params)
+            headers = request.headers
+            body = self.call("DescribeBackupDownloadTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeBackupDownloadTaskResponse()
@@ -264,7 +272,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeClientConnections", params)
+            headers = request.headers
+            body = self.call("DescribeClientConnections", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeClientConnectionsResponse()
@@ -292,7 +301,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBBackups", params)
+            headers = request.headers
+            body = self.call("DescribeDBBackups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBBackupsResponse()
@@ -320,7 +330,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstanceDeal", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstanceDeal", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstanceDealResponse()
@@ -348,7 +359,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeDBInstances", params)
+            headers = request.headers
+            body = self.call("DescribeDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeDBInstancesResponse()
@@ -376,7 +388,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeInstanceParams", params)
+            headers = request.headers
+            body = self.call("DescribeInstanceParams", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeInstanceParamsResponse()
@@ -404,7 +417,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSecurityGroup", params)
+            headers = request.headers
+            body = self.call("DescribeSecurityGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSecurityGroupResponse()
@@ -432,7 +446,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowLogPatterns", params)
+            headers = request.headers
+            body = self.call("DescribeSlowLogPatterns", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowLogPatternsResponse()
@@ -460,7 +475,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSlowLogs", params)
+            headers = request.headers
+            body = self.call("DescribeSlowLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSlowLogsResponse()
@@ -488,7 +504,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeSpecInfo", params)
+            headers = request.headers
+            body = self.call("DescribeSpecInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeSpecInfoResponse()
@@ -516,7 +533,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("FlushInstanceRouterConfig", params)
+            headers = request.headers
+            body = self.call("FlushInstanceRouterConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.FlushInstanceRouterConfigResponse()
@@ -544,7 +562,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceCreateDBInstances", params)
+            headers = request.headers
+            body = self.call("InquirePriceCreateDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceCreateDBInstancesResponse()
@@ -572,7 +591,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceModifyDBInstanceSpec", params)
+            headers = request.headers
+            body = self.call("InquirePriceModifyDBInstanceSpec", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceModifyDBInstanceSpecResponse()
@@ -600,7 +620,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("InquirePriceRenewDBInstances", params)
+            headers = request.headers
+            body = self.call("InquirePriceRenewDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.InquirePriceRenewDBInstancesResponse()
@@ -628,7 +649,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("IsolateDBInstance", params)
+            headers = request.headers
+            body = self.call("IsolateDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.IsolateDBInstanceResponse()
@@ -656,7 +678,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceSecurityGroup", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceSecurityGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceSecurityGroupResponse()
@@ -684,7 +707,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyDBInstanceSpec", params)
+            headers = request.headers
+            body = self.call("ModifyDBInstanceSpec", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyDBInstanceSpecResponse()
@@ -712,7 +736,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("OfflineIsolatedDBInstance", params)
+            headers = request.headers
+            body = self.call("OfflineIsolatedDBInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.OfflineIsolatedDBInstanceResponse()
@@ -740,7 +765,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenameInstance", params)
+            headers = request.headers
+            body = self.call("RenameInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenameInstanceResponse()
@@ -768,7 +794,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RenewDBInstances", params)
+            headers = request.headers
+            body = self.call("RenewDBInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RenewDBInstancesResponse()
@@ -796,7 +823,8 @@ class MongodbClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResetDBInstancePassword", params)
+            headers = request.headers
+            body = self.call("ResetDBInstancePassword", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResetDBInstancePasswordResponse()
